@@ -191,8 +191,8 @@ void DeviceManager::deviceAdded(GstDevice* device)
 
 void DeviceManager::deviceRemoved(GstDevice* device)
 {
-    auto st(gst_device_get_properties(device));
-    auto udi = structureValue(st, "sysfs.path");
+    auto st = gst_device_get_properties(device);
+    auto udi = udiFromProperties(st);
 
     for(int i = 0, c = m_deviceList.size(); i<c; ++i) {
         auto dev = m_deviceList.at(i);
